"""
This script is executed when running `python -m jupytray`.
"""

from .tray_app import run_app


run_app()
